/**
 * @package SJ Categories for VirtueMart
 * @version 2.2.0
 * @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 * @copyright (c) 2014 YouTech Company. All Rights Reserved.
 * @author YouTech Company http://www.smartaddons.com
 *
 */

.clear {
    clear: both;
}

.sj-categories {
    margin: 20px 0;
    overflow: hidden;
}

.sj-categories .intro_text,
.sj-categories .footer_text {
    margin: 10px 0px;
}

.sj-categories .cat-wrap {
    width: 100%;
    display: inline-block;
}

/*############################################## Css Device ##################################*/
.sj-categories.lt-ie9.preset01-1 .cat-wrap .content-box {
    float: left;
    margin: 0;
    width: 100%;
}

.sj-categories.lt-ie9.preset01-2 .cat-wrap .content-box {
    float: left;
    margin: 0 1%;
    width: 48%;
}

.sj-categories.lt-ie9.preset01-3 .cat-wrap .content-box {
    float: left;
    margin: 0 1%;
    width: 31.3333%;
}

.sj-categories.lt-ie9.preset01-4 .cat-wrap .content-box {
    float: left;
    margin: 0 1%;
    width: 23%;
}

.sj-categories.lt-ie9.preset01-5 .cat-wrap .content-box {
    float: left;
    margin: 0 1%;
    width: 18%;
}

.sj-categories.lt-ie9.preset01-6 .cat-wrap .content-box {
    float: left;
    margin: 0 1%;
    width: 14.6666%;
}

.sj-categories.lt-ie9.preset01-1 .clr1,
.sj-categories.lt-ie9.preset01-2 .clr2,
.sj-categories.lt-ie9.preset01-3 .clr3,
.sj-categories.lt-ie9.preset01-4 .clr4,
.sj-categories.lt-ie9.preset01-5 .clr5,
.sj-categories.lt-ie9.preset01-6 .clr6 {
    clear: both;
}

@media all and (max-width: 320px) {
    .sj-categories.preset05-1 .cat-wrap .content-box {
        float: left;
        margin: 0;
        width: 100%;
    }

    .sj-categories.preset05-2 .cat-wrap .content-box {
        float: left;
        margin: 0 1%;
        width: 48%;
    }

    .sj-categories.preset05-3 .cat-wrap .content-box {
        float: left;
        margin: 0 1%;
        width: 31.3333%;
    }

    .sj-categories.preset05-4 .cat-wrap .content-box {
        float: left;
        margin: 0 1%;
        width: 23%;
    }

    .sj-categories.preset05-5 .cat-wrap .content-box {
        float: left;
        margin: 0 1%;
        width: 18%;
    }

    .sj-categories.preset05-6 .cat-wrap .content-box {
        float: left;
        margin: 0 1%;
        width: 14.6666%;
    }

    .sj-categories.preset05-1 .clr1,
    .sj-categories.preset05-2 .clr2,
    .sj-categories.preset05-3 .clr3,
    .sj-categories.preset05-4 .clr4,
    .sj-categories.preset05-5 .clr5,
    .sj-categories.preset05-6 .clr6 {
        clear: both;
    }
}

@media all and (min-width: 321px) and (max-width: 480px) {
    .sj-categories.preset04-1 .cat-wrap .content-box {
        float: left;
        margin: 0;
        width: 100%;
    }

    .sj-categories.preset04-2 .cat-wrap .content-box {
        float: left;
        margin: 0 1%;
        width: 48%;
    }

    .sj-categories.preset04-3 .cat-wrap .content-box {
        float: left;
        margin: 0 1%;
        width: 31.3333%;
    }

    .sj-categories.preset04-4 .cat-wrap .content-box {
        float: left;
        margin: 0 1%;
        width: 23%;
    }

    .sj-categories.preset04-5 .cat-wrap .content-box {
        float: left;
        margin: 0 1%;
        width: 18%;
    }

    .sj-categories.preset04-6 .cat-wrap .content-box {
        float: left;
        margin: 0 1%;
        width: 14.6666%;
    }

    .sj-categories.preset04-1 .clr1,
    .sj-categories.preset04-2 .clr2,
    .sj-categories.preset04-3 .clr3,
    .sj-categories.preset04-4 .clr4,
    .sj-categories.preset04-5 .clr5,
    .sj-categories.preset04-6 .clr6 {
        clear: both;
    }
}

@media all and (min-width: 481px) and (max-width: 768px) {
    .sj-categories.preset03-1 .cat-wrap .content-box {
        float: left;
        margin: 0;
        width: 100%;
    }

    .sj-categories.preset03-2 .cat-wrap .content-box {
        float: left;
        margin: 0 1%;
        width: 48%;
    }

    .sj-categories.preset03-3 .cat-wrap .content-box {
        float: left;
        margin: 0 1%;
        width: 31.3333%;
    }

    .sj-categories.preset03-4 .cat-wrap .content-box {
        float: left;
        margin: 0 1%;
        width: 23%;
    }

    .sj-categories.preset03-5 .cat-wrap .content-box {
        float: left;
        margin: 0 1%;
        width: 18%;
    }

    .sj-categories.preset03-6 .cat-wrap .content-box {
        float: left;
        margin: 0 1%;
        width: 14.6666%;
    }

    .sj-categories.preset03-1 .clr1,
    .sj-categories.preset03-2 .clr2,
    .sj-categories.preset03-3 .clr3,
    .sj-categories.preset03-4 .clr4,
    .sj-categories.preset03-5 .clr5,
    .sj-categories.preset03-6 .clr6 {
        clear: both;
    }
}

@media all and (min-width: 769px) and (max-width: 1200px) {
    .sj-categories.preset02-1 .cat-wrap .content-box {
        float: left;
        margin: 0;
        width: 100%;
    }

    .sj-categories.preset02-2 .cat-wrap .content-box {
        float: left;
        margin: 0 1%;
        width: 48%;
    }

    .sj-categories.preset02-3 .cat-wrap .content-box {
        float: left;
        margin: 0 1%;
        width: 31.3333%;
    }

    .sj-categories.preset02-4 .cat-wrap .content-box {
        float: left;
        margin: 0 1%;
        width: 23%;
    }

    .sj-categories.preset02-5 .cat-wrap .content-box {
        float: left;
        margin: 0 1%;
        width: 18%;
    }

    .sj-categories.preset02-6 .cat-wrap .content-box {
        float: left;
        margin: 0 1%;
        width: 14.6666%;
    }

    .sj-categories.preset02-1 .clr1,
    .sj-categories.preset02-2 .clr2,
    .sj-categories.preset02-3 .clr3,
    .sj-categories.preset02-4 .clr4,
    .sj-categories.preset02-5 .clr5,
    .sj-categories.preset02-6 .clr6 {
        clear: both;
    }
}

@media all and (min-width: 1201px) {
    .sj-categories.preset01-1 .cat-wrap .content-box {
        float: left;
        margin: 0;
        width: 100%;
    }

    .sj-categories.preset01-2 .cat-wrap .content-box {
        float: left;
        margin: 0 1%;
        width: 48%;
    }

    .sj-categories.preset01-3 .cat-wrap .content-box {
        float: left;
        margin: 0 1%;
        width: 31.3333%;
    }

    .sj-categories.preset01-4 .cat-wrap .content-box {
        float: left;
        margin: 0 1%;
        width: 23%;
    }

    .sj-categories.preset01-5 .cat-wrap .content-box {
        float: left;
        margin: 0 1%;
        width: 18%;
    }

    .sj-categories.preset01-6 .cat-wrap .content-box {
        float: left;
        margin: 0 1%;
        width: 14.6666%;
    }

    .sj-categories.preset01-1 .clr1,
    .sj-categories.preset01-2 .clr2,
    .sj-categories.preset01-3 .clr3,
    .sj-categories.preset01-4 .clr4,
    .sj-categories.preset01-5 .clr5,
    .sj-categories.preset01-6 .clr6 {
        clear: both;
    }
}

/*################################# End css Device #############################################*/

.sj-categories .cat-wrap .content-box {
    overflow: hidden;
    line-height: 20px;
    padding-bottom: 15px;
}

.sj-categories .cat-wrap .content-box .cat-title a {
    font-weight: bold;
}

.sj-categories .cat-wrap.theme1 .content-box .child-cat .child-cat-title {
    float: none;
    padding: 0;
}

.sj-categories .cat-wrap .content-box .child-cat .child-cat-title {
    float: left;
    padding-right: 5px;
}

.sj-categories .cat-wrap.theme3 .content-box .child-cat .child-cat-title {
    float: none;
    display: inline;
}

.sj-categories .cat-wrap.theme2 .content-box img,
.sj-categories .cat-wrap.theme3 .content-box img {
    width: 100%;
    display: block;
    max-width: 100%;
    box-shadow: #000 0em 0em 0em;
    -webkit-transition: all 0.2s linear;
    -moz-transition: all 0.2s linear;
    -o-transition: all 0.2s linear;
    -ms-transition: all 0.2s linear;
    transition: all 0.2s linear;
}

.sj-categories .cat-wrap .image-cat {
    overflow: hidden;
}

.sj-categories .cat-wrap.theme4 .sj-categories-content .child-cat .child-cat-info .image-cat {
    float: left;
    width: 30%;
    margin: 0;
    margin: 0 13px 0 0;
    overflow: hidden;
}

.sj-categories .cat-wrap.theme4 .sj-categories-content .child-cat .child-cat-info .image-cat a {
    display: block;
    border: 0;
    width: 100%;
    float: left;
    overflow: hidden;
}

.sj-categories .cat-wrap.theme4 .sj-categories-content .child-cat .child-cat-info .image-cat img {
    width: 100%;
    display: block;
    max-width: 100%;
    box-shadow: #000 0em 0em 0em;
    -webkit-transition: all 0.2s linear;
    -moz-transition: all 0.2s linear;
    -o-transition: all 0.2s linear;
    -ms-transition: all 0.2s linear;
    transition: all 0.2s linear;
}

.sj-categories .cat-wrap img:hover {
    opacity: 0.8;
    filter: alpha(opacity=80);
    box-shadow: #000 0em 0em 0em;
    -webkit-transform: scale(1.1, 1.1);
    -moz-transform: scale(1.1, 1.1);
    -o-transform: scale(1.1, 1.1);
    -ms-transform: scale(1.1, 1.1);
    transform: scale(1.1, 1.1);
}

/*#################### css for theme 2 ######################*/
.sj-categories .cat-wrap.theme2 .arrow {
    background: url(../images/arrow.png) no-repeat;
    margin-top: 6px;
    width: 6px;
    height: 7px;
    float: left;
    padding-right: 5px;
}

.sj-categories .cat-wrap.theme2 .content-box .parent-cat {
    float: left;
    margin: 0 10px 10px 0;
    max-width: 50%;
}

.sj-categories .cat-wrap.theme2 .content-box .parent-cat .cat-title {
    padding-bottom: 5px;
}

.sj-categories .cat-wrap.theme2 .content-box .child-cat .child-cat-title {
    float: none;
}

/*#################### css for theme 3 ######################*/
.sj-categories .cat-wrap.theme3 .content-box .cat-title {
    padding-top: 5px;
}

/*#################### css for theme 4 ######################*/
.sj-categories.theme4 {
    padding: 1px;
}

.sj-categories .cat-wrap.theme4 {
    border: 1px solid #CCCCCC;
    width: 100%;
    margin: 0 -1px;
    height: auto;
}

.sj-categories .cat-wrap.theme4 .sj-categories-inner {
    width: 100%;
    float: left;
    padding: 0px;
    margin: 0px;
}

.sj-categories .cat-wrap.theme4 .sj-categories-heading {
    background: url(../images/bk.gif) repeat-x;
    height: 24px;
    cursor: pointer;
}

.sj-categories .cat-wrap.theme4 .sj-categories-heading .icon_left {
    background: url(../images/icon.png) no-repeat;
    margin-top: 8px;
    width: 7px;
    height: 7px;
    margin-left: 5px;
    float: left
}

.sj-categories .cat-wrap.theme4 .sj-categories-heading .icon_right {
    background: url(../images/plus.gif) no-repeat;
    margin-top: 5px;
    margin-right: 5px;
    width: 13px;
    height: 13px;
    float: right
}

.sj-categories .cat-wrap.theme4 .sj-categories-inner.selected .icon_right {
    background: url(../images/minus.gif) no-repeat;
}

.sj-categories .cat-wrap.theme4 .sj-categories-heading .cat-title {
    padding-left: 5px;
    line-height: 24px;
    float: left;
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis;
    max-width: 75%;
}

.sj-categories .cat-wrap.theme4 .sj-categories-content {

    height: 0;
    overflow: hidden;
    width: 100%;
}

/* .sj-categories .cat-wrap.theme4 .sj-categories-inner.selected .sj-categories-content{
	margin:10px;
    margin-bottom:10px;
} */

.sj-categories .cat-wrap.theme4 .sj-categories-content .child-cat {
    padding: 15px;
    padding-bottom: 0px;
    overflow: hidden;

}

.sj-categories .cat-wrap.theme4 .sj-categories-content .child-cat.cat-lastitem {
    padding-bottom: 15px;
}

.sj-categories .cat-wrap.theme4 .sj-categories-content .child-cat.subcat-empty {
    padding: 10px;
}

.sj-categories .cat-wrap.theme4 .sj-categories-content .child-cat .child-cat-info {
    display: block;
}

.sj-categories .cat-wrap.theme4 .sj-categories-content .child-cat .image-cat {
    float: left;
    margin-right: 10px;
    overflow: hidden;
}

/* .sj-categories .cat-wrap.theme4 .sj-categories-content .child-cat .child-cat-desc{
	float:left;
} */
.sj-categories .cat-wrap.theme4 .sj-categories-content .child-cat .child-cat-desc .child-cat-title,
.sj-categories .cat-wrap.theme4 .sj-categories-content .child-cat .child-cat-desc .child-cat-title a {
    float: left;
    font-weight: bold;
    padding-right: 3px;
}

@media all and (max-width: 480px) {
    .sj-categories .cat-wrap.theme2 .content-box .parent-cat {
        margin: 0 0 10px 0;
        width: 100%;
        float: none;
        max-width: 100%;
    }

    .sj-categories .cat-wrap.theme2 .content-box img {
        width: 100%;
        display: block;
        max-width: 100%;
    }

}

.cf:before,
.cf:after {
    content: " ";
    display: table;
}

.cf:after {
    clear: both;
}
