.slider {

  width: 300px;

}



.slider > .dragger {
  
  border: 1px solid #1a3867;
  width: 16px;
  height: 16px;

}









.slider > .track, .slider > .highlight-track {

  background: #ccc;

  background: -webkit-linear-gradient(top, #bbb, #ddd);

  background: -moz-linear-gradient(top, #bbb, #ddd);

  background: linear-gradient(top, #bbb, #ddd);



  -webkit-box-shadow: inset 0 2px 4px rgba(0,0,0,0.1);

  -moz-box-shadow: inset 0 2px 4px rgba(0,0,0,0.1);

  box-shadow: inset 0 2px 4px rgba(0,0,0,0.1);



  -webkit-border-radius: 8px;

  -moz-border-radius: 8px;

  border-radius: 8px;



  border: 1px solid #aaa;

  height: 4px;

}



.slider > .highlight-track {

	background-color: #8DCA09;

	background: -webkit-linear-gradient(top, #8DCA09, #72A307);

	background: -moz-linear-gradient(top, #8DCA09, #72A307);

	background: linear-gradient(top, #8DCA09, #72A307);

	

	border-color: #496805;

}



