/**
 * @package SJ Extra Slider for Content
 * @version 3.0.0
 * @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 * @copyright (c) 2014 YouTech Company. All Rights Reserved.
 * @author YouTech Company http://www.smartaddons.com
 *
 */

.sj-extraslider .extraslider-inner .item-wrap {
    overflow: hidden;
}

.sj-extraslider .extraslider-inner .item-wrap .item-image {
    width: 100%;
    overflow: hidden;
}

.sj-extraslider .extraslider-inner .item-wrap .item-image img {
    width: 100%;
    max-width: 100%;
    border: 0;
    box-shadow: #000 0em 0em 0em;
}

.sj-extraslider .extraslider-inner .item-wrap .item-info {
    /*     padding: 10px; */
    width: 100%;
}

.sj-extraslider .extraslider-inner .item-wrap.style2 .item-info {
    background: #333;
}

.sj-extraslider .extraslider-inner .item-wrap .item-info .item-content {
    margin: 10px 10px 10px 10px;
    /*     padding:10px; */
}

.sj-extraslider .extraslider-inner .item-wrap.style2 .item-info .item-content {
    margin-bottom: 10px;
}

.sj-extraslider .extraslider-inner .item-wrap .item-info .item-title {
    padding: 10px 10px 0 10px;
    font-weight: bold;
    margin-bottom: 0px;
    text-transform: uppercase;
}

.sj-extraslider .extraslider-inner .item-wrap .item-info .item-description {
    color: #fff;
}

.sj-extraslider .extraslider-inner .item-wrap .item-info .item-readmore {
    text-align: right;
    margin: 0px 0 0 0;
    font-weight: bold;
}

/*####################### item-style4 ##########################*/
.sj-extraslider .extraslider-inner .item-wrap.style4 {
    position: relative;
}

.sj-extraslider .extraslider-inner .item-wrap.style4 img {
    -webkit-transition: all 0.2s ease-in;
    -moz-transition: all 0.2s ease-in;
    -o-transition: all 0.2s ease-in;
    -ms-transition: all 0.2s ease-in;
    transition: all 0.2s ease-in;
    box-shadow: #000 0em 0em 0em;
}

.sj-extraslider .extraslider-inner .item-wrap.style4 .item-info {
    position: absolute;
    top: 0;
    height: 100%;
    text-align: center;
    padding: 0;
    background: url(../images/background.png) repeat;
    -ms-filter: "progid: DXImageTransform.Microsoft.Alpha(Opacity=0)";
    filter: alpha(opacity=0);
    opacity: 0;
    -webkit-transform: translate(460px, -100px) rotate(180deg);
    -moz-transform: translate(460px, -100px) rotate(180deg);
    -o-transform: translate(460px, -100px) rotate(180deg);
    -ms-transform: translate(460px, -100px) rotate(180deg);
    transform: translate(460px, -100px) rotate(180deg);
    -webkit-transition: all 0.2s 0.4s ease-in-out;
    -moz-transition: all 0.2s 0.4s ease-in-out;
    -o-transition: all 0.2s 0.4s ease-in-out;
    -ms-transition: all 0.2s 0.4s ease-in-out;
    transition: all 0.2s 0.4s ease-in-out;
    box-shadow: #000 0em 0em 0em;
}

.sj-extraslider .extraslider-inner .item-wrap.style4 .item-title {
    -webkit-transform: translateY(-100px);
    -moz-transform: translateY(-100px);
    -o-transform: translateY(-100px);
    -ms-transform: translateY(-100px);
    transform: translateY(-100px);
    -webkit-transition: all 0.2s ease-in-out;
    -moz-transition: all 0.2s ease-in-out;
    -o-transition: all 0.2s ease-in-out;
    -ms-transition: all 0.2s ease-in-out;
    transition: all 0.2s ease-in-out;
    padding: 6px;
    background: url(../images/background.png) repeat;
    margin: 5% 0 0 0;
    text-transform: uppercase;
    box-shadow: #000 0em 0em 0em;
}

.sj-extraslider .extraslider-inner .item-wrap.style4 .item-readmore a,
.sj-extraslider .extraslider-inner .item-wrap.style4 .item-title a {
    color: #FFF;
}

.sj-extraslider .extraslider-inner .item-wrap.style4 .item-price,
.sj-extraslider .extraslider-inner .item-wrap.style4 .item-description {
    -webkit-transform: translateX(300px) rotate(90deg);
    -moz-transform: translateX(300px) rotate(90deg);
    -o-transform: translateX(300px) rotate(90deg);
    -ms-transform: translateX(300px) rotate(90deg);
    transform: translateX(300px) rotate(90deg);
    -webkit-transition: all 0.2s ease-in-out;
    -moz-transition: all 0.2s ease-in-out;
    -o-transition: all 0.2s ease-in-out;
    -ms-transition: all 0.2s ease-in-out;
    transition: all 0.2s ease-in-out;
    /*     padding:10px; */
    text-align: left;
    box-shadow: #000 0em 0em 0em;
}

.sj-extraslider .extraslider-inner .item-wrap.style4 .item-price {
    text-align: center;
}

.sj-extraslider .extraslider-inner .item-wrap.style4:hover .item-info {
    filter: alpha(opacity=100);
    opacity: 1;
    -webkit-transition-delay: 0s;
    -moz-transition-delay: 0s;
    -o-transition-delay: 0s;
    -ms-transition-delay: 0s;
    transition-delay: 0s;
    -webkit-transform: translate(0px, 0px);
    -moz-transform: translate(0px, 0px);
    -o-transform: translate(0px, 0px);
    -ms-transform: translate(0px, 0px);
    transform: translate(0px, 0px);
    box-shadow: #000 0em 0em 0em;
}

.sj-extraslider .extraslider-inner .item-wrap.style4:hover .item-title {
    -webkit-transform: translateY(0px);
    -moz-transform: translateY(0px);
    -o-transform: translateY(0px);
    -ms-transform: translateY(0px);
    transform: translateY(0px);
    -webkit-transition-delay: 0.5s;
    -moz-transition-delay: 0.5s;
    -o-transition-delay: 0.5s;
    -ms-transition-delay: 0.5s;
    transition-delay: 0.5s;
    box-shadow: #000 0em 0em 0em;
}

.sj-extraslider .extraslider-inner .item-wrap.style4:hover .item-description {
    -webkit-transform: translateX(0px) rotate(0deg);
    -moz-transform: translateX(0px) rotate(0deg);
    -o-transform: translateX(0px) rotate(0deg);
    -ms-transform: translateX(0px) rotate(0deg);
    transform: translateX(0px) rotate(0deg);
    -webkit-transition-delay: 0.4s;
    -moz-transition-delay: 0.4s;
    -o-transition-delay: 0.4s;
    -ms-transition-delay: 0.4s;
    transition-delay: 0.4s;
    box-shadow: #000 0em 0em 0em;
}

.sj-extraslider .extraslider-inner .item-wrap.style4:hover .item-price,
.sj-extraslider .extraslider-inner .item-wrap.style4:hover .item-readmore {
    -webkit-transform: translateY(0px);
    -moz-transform: translateY(0px);
    -o-transform: translateY(0px);
    -ms-transform: translateY(0px);
    transform: translateY(0px);
    -webkit-transition-delay: 0.3s;
    -moz-transition-delay: 0.3s;
    -o-transition-delay: 0.3s;
    -ms-transition-delay: 0.3s;
    transition-delay: 0.3s;
    box-shadow: #000 0em 0em 0em;
}

.sj-extraslider .extraslider-inner .item-wrap.style4 .item-readmore {
    display: inline-block;
    text-decoration: none;
    padding: 3px 10px;
    background: #000;
    -webkit-box-shadow: 0 0 1px #000;
    -moz-box-shadow: 0 0 1px #000;
    box-shadow: 0 0 1px #000;
    -webkit-transform: translateY(-200px);
    -moz-transform: translateY(-200px);
    -o-transform: translateY(-200px);
    -ms-transform: translateY(-200px);
    transform: translateY(-200px);
    -webkit-transition: all 0.2s ease-in-out;
    -moz-transition: all 0.2s ease-in-out;
    -o-transition: all 0.2s ease-in-out;
    -ms-transition: all 0.2s ease-in-out;
    transition: all 0.2s ease-in-out;
}

/*####################### item-style7 ##########################*/
.sj-extraslider .extraslider-inner .item-wrap.style7 {
    position: relative;
}

.sj-extraslider .extraslider-inner .item-wrap.style7 .item-info {
    position: absolute;
    top: 0;
    left: 0;
    height: 100%;
    text-align: center;
    padding: 0;
    background: url(../images/bg-white.png);
    top: -100%;
    -webkit-transition: all 0.3s ease-out 0.5s;
    -moz-transition: all 0.3s ease-out 0.5s;
    -o-transition: all 0.3s ease-out 0.5s;
    -ms-transition: all 0.3s ease-out 0.5s;
    transition: all 0.3s ease-out 0.5s;
}

.sj-extraslider .extraslider-inner .item-wrap.style7 .item-info .item-content {
    padding: 10px;
}

.sj-extraslider .extraslider-inner .item-wrap.style7 .item-title {
    background: #333;
    color: #FFFFFF;
    font-size: 17px;
    margin: 5% 0 0 0;
    padding: 7px;
    position: relative;
    text-align: center;
    text-transform: uppercase;
    -webkit-transform: translateY(-200%);
    -moz-transform: translateY(-200%);
    -o-transform: translateY(-200%);
    -ms-transform: translateY(-200%);
    transform: translateY(-200%);
    -webkit-transition: all 0.2s ease-in-out 0.1s;
    -moz-transition: all 0.2s ease-in-out 0.1s;
    -o-transition: all 0.2s ease-in-out 0.1s;
    -ms-transition: all 0.2s ease-in-out 0.1s;
    transition: all 0.2s ease-in-out 0.1s;
}

.sj-extraslider .extraslider-inner .item-wrap.style7 .item-price,
.sj-extraslider .extraslider-inner .item-wrap.style7 .item-description {
    text-align: left;
    color: #333;
    -webkit-transform: translateY(-500%);
    -moz-transform: translateY(-500%);
    -o-transform: translateY(-500%);
    -ms-transform: translateY(-500%);
    transform: translateY(-500%);
    -webkit-transition: all 0.2s ease-in-out 0.2s;
    -moz-transition: all 0.2s ease-in-out 0.2s;
    -o-transition: all 0.2s ease-in-out 0.2s;
    -ms-transition: all 0.2s ease-in-out 0.2s;
    transition: all 0.2s ease-in-out 0.2s;
}

.sj-extraslider .extraslider-inner .item-wrap.style7 .item-price {
    text-align: center;
    color: #F30000;
}

.sj-extraslider .extraslider-inner .item-wrap.style7 .item-tags {
    text-align: left;
    color: #333;
    -webkit-transform: translateY(-700%);
    -moz-transform: translateY(-700%);
    -o-transform: translateY(-700%);
    -ms-transform: translateY(-700%);
    transform: translateY(-700%);
    -webkit-transition: all 0.2s ease-in-out 0.2s;
    -moz-transition: all 0.2s ease-in-out 0.2s;
    -o-transition: all 0.2s ease-in-out 0.2s;
    -ms-transition: all 0.2s ease-in-out 0.2s;
    transition: all 0.2s ease-in-out 0.2s;
}

.sj-extraslider .extraslider-inner .item-wrap.style7 .item-readmore {
    background: none repeat scroll 0 0 #000000;
    box-shadow: 0 0 1px #000000;
    color: #FFFFFF;
    display: inline-block;
    padding: 2px 5px;
    text-decoration: none;
    -webkit-transform: translateY(-1000%);
    -moz-transform: translateY(-1000%);
    -o-transform: translateY(-1000%);
    -ms-transform: translateY(-1000%);
    transform: translateY(-1000%);
    -webkit-transition: all 0.2s ease-in-out 0.3s;
    -moz-transition: all 0.2s ease-in-out 0.3s;
    -o-transition: all 0.2s ease-in-out 0.3s;
    -ms-transition: all 0.2s ease-in-out 0.3s;
    transition: all 0.2s ease-in-out 0.3s;
}

.sj-extraslider .extraslider-inner .item-wrap.style7:hover .item-info {
    top: 0px;
    -webkit-transition-delay: 0s;
    -moz-transition-delay: 0s;
    -o-transition-delay: 0s;
    -ms-transition-delay: 0s;
    transition-delay: 0s;
    -webkit-animation: bounceY 0.9s linear;
    -moz-animation: bounceY 0.9s linear;
    -ms-animation: bounceY 0.9s linear;
    animation: bounceY 0.9s linear;
}

.sj-extraslider .extraslider-inner .item-wrap.style7:hover .item-title {
    -webkit-transform: translateY(0%);
    -moz-transform: translateY(0%);
    -o-transform: translateY(0%);
    -ms-transform: translateY(0%);
    transform: translateY(0%);
    -webkit-transition-delay: 0.2s;
    -moz-transition-delay: 0.2s;
    -o-transition-delay: 0.2s;
    -ms-transition-delay: 0.2s;
    transition-delay: 0.2s;
}

.sj-extraslider .extraslider-inner .item-wrap.style7:hover .item-description {
    -webkit-transform: translateY(0%);
    -moz-transform: translateY(0%);
    -o-transform: translateY(0%);
    -ms-transform: translateY(0%);
    transform: translateY(0%);
    -webkit-transition-delay: 0.2s;
    -moz-transition-delay: 0.2s;
    -o-transition-delay: 0.2s;
    -ms-transition-delay: 0.2s;
    transition-delay: 0.2s;
}

.sj-extraslider .extraslider-inner .item-wrap.style7:hover .item-tags {
    -webkit-transform: translateY(0%);
    -moz-transform: translateY(0%);
    -o-transform: translateY(0%);
    -ms-transform: translateY(0%);
    transform: translateY(0%);
    -webkit-transition-delay: 0.2s;
    -moz-transition-delay: 0.2s;
    -o-transition-delay: 0.2s;
    -ms-transition-delay: 0.2s;
    transition-delay: 0.2s;
}

.sj-extraslider .extraslider-inner .item-wrap.style7:hover .item-price,
.sj-extraslider .extraslider-inner .item-wrap.style7:hover .item-readmore {
    -webkit-transform: translateY(0%);
    -moz-transform: translateY(0%);
    -o-transform: translateY(0%);
    -ms-transform: translateY(0%);
    transform: translateY(0%);
    -webkit-transition-delay: 0s;
    -moz-transition-delay: 0s;
    -o-transition-delay: 0s;
    -ms-transition-delay: 0s;
    transition-delay: 0s;
}

.sj-extraslider .extraslider-inner .item-wrap.style7 .item-readmore a {
    color: #FFF;
}

.sj-extraslider .extraslider-inner .item-wrap.style7 .item-title a {
    color: #FFF;
    text-transform: uppercase;
    font-weight: bold;
}

@keyframes bounceY {
    0% {
        transform: translateY(-103%);
    }
    40% {
        transform: translateY(-50%);
    }
    65% {
        transform: translateY(-25%);
    }
    82% {
        transform: translateY(-12%);
    }
    92% {
        transform: translateY(-5%);
    }
    55%, 75%, 87%, 97%, 100% {
        transform: translateY(0%);
    }
}

@-moz-keyframes bounceY {
    0% {
        -moz-transform: translateY(-1023%);
    }
    40% {
        -moz-transform: translateY(-50%);
    }
    65% {
        -moz-transform: translateY(-25%);
    }
    82% {
        -moz-transform: translateY(-12%);
    }
    92% {
        -moz-transform: translateY(-5%);
    }
    55%, 75%, 87%, 97%, 100% {
        -moz-transform: translateY(0%);
    }
}

@-webkit-keyframes bounceY {
    0% {
        -webkit-transform: translateY(-103%);
    }
    40% {
        -webkit-transform: translateY(-50%);
    }
    65% {
        -webkit-transform: translateY(-25%);
    }
    82% {
        -webkit-transform: translateY(-12%);
    }
    92% {
        -webkit-transform: translateY(-5%);
    }
    55%, 75%, 87%, 97%, 100% {
        -webkit-transform: translateY(0%);
    }
}

/*####################### item-style9 ##########################*/
.sj-extraslider .extraslider-inner .item-wrap.style9 {
    position: relative;
}

.sj-extraslider .extraslider-inner .item-wrap.style9 img {
    -webkit-transform: scaleY(1);
    -moz-transform: scaleY(1);
    -o-transform: scaleY(1);
    -ms-transform: scaleY(1);
    transform: scaleY(1);
    -webkit-transition: all 0.7s ease-in-out;
    -moz-transition: all 0.7s ease-in-out;
    -o-transition: all 0.7s ease-in-out;
    -ms-transition: all 0.7s ease-in-out;
    transition: all 0.7s ease-in-out;
    box-shadow: #000 0em 0em 0em;
}

.sj-extraslider .extraslider-inner .item-wrap.style9 .item-info {
    text-align: center;
    position: absolute;
    top: 0;
    left: 0;
    height: 100%;
    background: #333;
    -webkit-transition: all 0.5s linear;
    -moz-transition: all 0.5s linear;
    -o-transition: all 0.5s linear;
    -ms-transition: all 0.5s linear;
    transition: all 0.5s linear;
    -ms-filter: "progid: DXImageTransform.Microsoft.Alpha(Opacity=0)";
    filter: alpha(opacity=0);
    opacity: 0;
}

.sj-extraslider .extraslider-inner .item-wrap.style9 .item-title {
    text-transform: uppercase;
    border-bottom: #666 solid 1px;
    background: transparent;
    margin: 0 10px 0 10px;
    padding-bottom: 7px;
    -webkit-transform: scale(0);
    -moz-transform: scale(0);
    -o-transform: scale(0);
    -ms-transform: scale(0);
    transform: scale(0);
    color: #333;
    -webkit-transition: all 0.5s linear;
    -moz-transition: all 0.5s linear;
    -o-transition: all 0.5s linear;
    -ms-transition: all 0.5s linear;
    transition: all 0.5s linear;
    -ms-filter: "progid: DXImageTransform.Microsoft.Alpha(Opacity=0)";
    filter: alpha(opacity=0);
    opacity: 0;
}

.sj-extraslider .extraslider-inner .item-wrap.style9 .item-price,
.sj-extraslider .extraslider-inner .item-wrap.style9 .item-description {
    text-align: left;
    color: #FFF;
    -ms-filter: "progid: DXImageTransform.Microsoft.Alpha(Opacity=0)";
    filter: alpha(opacity=0);
    opacity: 0;
    -webkit-transform: scale(0);
    -moz-transform: scale(0);
    -o-transform: scale(0);
    -ms-transform: scale(0);
    transform: scale(0);
    -webkit-transition: all 0.5s linear;
    -moz-transition: all 0.5s linear;
    -o-transition: all 0.5s linear;
    -ms-transition: all 0.5s linear;
    transition: all 0.5s linear;
}

.sj-extraslider .extraslider-inner .item-wrap.style9 .item-readmore {
    text-align: center;
    background: none repeat scroll 0 0 #000000;
    box-shadow: 0 0 1px #000000;
    color: #FFFFFF;
    display: inline-block;
    padding: 2px 10px;
    -ms-filter: "progid: DXImageTransform.Microsoft.Alpha(Opacity=0)";
    filter: alpha(opacity=0);
    opacity: 0;
    -webkit-transform: scale(0);
    -moz-transform: scale(0);
    -o-transform: scale(0);
    -ms-transform: scale(0);
    transform: scale(0);
    -webkit-transition: all 0.5s linear;
    -moz-transition: all 0.5s linear;
    -o-transition: all 0.5s linear;
    -ms-transition: all 0.5s linear;
    transition: all 0.5s linear;
}

.sj-extraslider .extraslider-inner .item-wrap.style9:hover img {
    -webkit-transform: scale(10);
    -moz-transform: scale(10);
    -o-transform: scale(10);
    -ms-transform: scale(10);
    transform: scale(10);
    -ms-filter: "progid: DXImageTransform.Microsoft.Alpha(Opacity=0)";
    filter: alpha(opacity=0);
    opacity: 0;
    box-shadow: #000 0em 0em 0em;
}

.sj-extraslider .extraslider-inner .item-wrap.style9:hover .item-info {
    -ms-filter: "progid: DXImageTransform.Microsoft.Alpha(Opacity=100)";
    filter: alpha(opacity=100);
    opacity: 1;
}

.sj-extraslider .extraslider-inner .item-wrap.style9:hover .item-price,
.sj-extraslider .extraslider-inner .item-wrap.style9:hover .item-title,
.sj-extraslider .extraslider-inner .item-wrap.style9:hover .item-description,
.sj-extraslider .extraslider-inner .item-wrap.style9:hover .item-readmore {
    -webkit-transform: scale(1);
    -moz-transform: scale(1);
    -o-transform: scale(1);
    -ms-transform: scale(1);
    transform: scale(1);
    -ms-filter: "progid: DXImageTransform.Microsoft.Alpha(Opacity=100)";
    filter: alpha(opacity=100);
    opacity: 1;
}

.sj-extraslider .extraslider-inner .item-wrap.style9 .item-readmore a {
    color: #FFF;
}

.sj-extraslider .extraslider-inner .item-wrap.style9 .item-title a {
    color: #FFF;
    text-transform: uppercase;
    font-weight: bold;
}

/*####################### item-style10 ##########################*/
.sj-extraslider .extraslider-inner .item-wrap.style10 {
    position: relative;
}

.sj-extraslider .extraslider-inner .item-wrap.style10 img {
    -webkit-transition: all 0.2s linear;
    -moz-transition: all 0.2s linear;
    -o-transition: all 0.2s linear;
    -ms-transition: all 0.2s linear;
    transition: all 0.2s linear;
    box-shadow: #000 0em 0em 0em;
}

.sj-extraslider .extraslider-inner .item-wrap.style10 .item-info {
    position: absolute;
    top: 0;
    left: 0;
    height: 100%;
    padding: 0;
    text-align: center;
    -ms-filter: "progid: DXImageTransform.Microsoft.Alpha(Opacity=0)";
    filter: alpha(opacity=0);
    opacity: 0;
    background-color: rgba(0, 0, 0, 0.7);
    -webkit-transition: all 0.4s ease-in-out;
    -moz-transition: all 0.4s ease-in-out;
    -o-transition: all 0.4s ease-in-out;
    -ms-transition: all 0.4s ease-in-out;
    transition: all 0.4s ease-in-out;
}

.sj-extraslider .extraslider-inner .item-wrap.style10 .item-info .item-content {
    padding: 5px;
}

.sj-extraslider .extraslider-inner .item-wrap.style10 .item-title {
    background: #FFF;
    opacity: 0.5;
    filter: alpha(opacity=50);
    font-size: 17px;
    padding: 5px;
    margin-top: 5%;
    text-align: center;
    text-transform: uppercase;
    -webkit-transform: translateY(-100px);
    -moz-transform: translateY(-100px);
    -o-transform: translateY(-100px);
    -ms-transform: translateY(-100px);
    transform: translateY(-100px);
    -webkit-transition: all 0.2s ease-in-out;
    -moz-transition: all 0.2s ease-in-out;
    -o-transition: all 0.2s ease-in-out;
    -ms-transition: all 0.2s ease-in-out;
    transition: all 0.2s ease-in-out;
}

.sj-extraslider .extraslider-inner .item-wrap.style10 .item-price,
.sj-extraslider .extraslider-inner .item-wrap.style10 .item-description {
    text-align: left;
    -webkit-transform: translateY(100px);
    -moz-transform: translateY(100px);
    -o-transform: translateY(100px);
    -ms-transform: translateY(100px);
    transform: translateY(100px);
    -ms-filter: "progid: DXImageTransform.Microsoft.Alpha(Opacity=0)";
    filter: alpha(opacity=0);
    opacity: 0;
    -webkit-transition: all 0.2s linear;
    -moz-transition: all 0.2s linear;
    -o-transition: all 0.2s linear;
    -ms-transition: all 0.2s linear;
    transition: all 0.2s linear;
}

.sj-extraslider .extraslider-inner .item-wrap.style10:hover img {
    -webkit-transform: scale(1.1, 1.1);
    -moz-transform: scale(1.1, 1.1);
    -o-transform: scale(1.1, 1.1);
    -ms-transform: scale(1.1, 1.1);
    transform: scale(1.1, 1.1);
    box-shadow: #000 0em 0em 0em;
}

.sj-extraslider .extraslider-inner .item-wrap.style10 .item-readmore {
    background: none repeat scroll 0 0 #000000;
    box-shadow: 0 0 1px #000000;
    color: #FFFFFF;
    display: inline-block;
    padding: 2px 10px;
    text-align: center;
    -ms-filter: "progid: DXImageTransform.Microsoft.Alpha(Opacity=0)";
    filter: alpha(opacity=0);
    opacity: 0;
    -webkit-transition: all 0.2s ease-in-out;
    -moz-transition: all 0.2s ease-in-out;
    -o-transition: all 0.2s ease-in-out;
    -ms-transition: all 0.2s ease-in-out;
    transition: all 0.2s ease-in-out;
}

.sj-extraslider .extraslider-inner .item-wrap.style10:hover .item-info {
    -ms-filter: "progid: DXImageTransform.Microsoft.Alpha(Opacity=100)";
    filter: alpha(opacity=100);
    opacity: 1;
}

.sj-extraslider .extraslider-inner .item-wrap.style10:hover .item-price,
.sj-extraslider .extraslider-inner .item-wrap.style10:hover .item-title,
.sj-extraslider .extraslider-inner .item-wrap.style10:hover .item-description,
.sj-extraslider .extraslider-inner .item-wrap.style10:hover .item-readmore {
    -webkit-transform: translateY(0px);
    -moz-transform: translateY(0px);
    -o-transform: translateY(0px);
    -ms-transform: translateY(0px);
    transform: translateY(0px);
}

.sj-extraslider .extraslider-inner .item-wrap.style10:hover .item-price,
.sj-extraslider .extraslider-inner .item-wrap.style10:hover .item-description,
.sj-extraslider .extraslider-inner .item-wrap.style10:hover .item-readmore {
    -ms-filter: "progid: DXImageTransform.Microsoft.Alpha(Opacity=100)";
    filter: alpha(opacity=100);
    opacity: 1;
}

.sj-extraslider .extraslider-inner .item-wrap.style10:hover .item-price,
.sj-extraslider .extraslider-inner .item-wrap.style10:hover .item-description {
    -webkit-transition-delay: 0.1s;
    -moz-transition-delay: 0.1s;
    -o-transition-delay: 0.1s;
    -ms-transition-delay: 0.1s;
    transition-delay: 0.1s;
}

.sj-extraslider .extraslider-inner .item-wrap.style10:hover .item-readmore {
    -webkit-transition-delay: 0.2s;
    -moz-transition-delay: 0.2s;
    -o-transition-delay: 0.2s;
    -ms-transition-delay: 0.2s;
    transition-delay: 0.2s;
}

.sj-extraslider .extraslider-inner .item-wrap.style10 .item-readmore a {
    color: #FFF;
}

.sj-extraslider .extraslider-inner .item-wrap.style10 .item-title a {
    color: #000;
    text-transform: uppercase;
    font-weight: bold;
}

/*####################### item-style11 ##########################*/
.sj-extraslider .extraslider-inner .item-wrap.style11 {
    position: relative;
}

.sj-extraslider .extraslider-inner .item-wrap.style11 img {
    -webkit-transition: all 0.5s ease-out;
    -moz-transition: all 0.5s ease-out;
    -o-transition: all 0.5s ease-out;
    -ms-transition: all 0.5s ease-out;
    transition: all 0.5s ease-out;
    -ms-filter: "progid: DXImageTransform.Microsoft.Alpha(Opacity=100)";
    filter: alpha(opacity=100);
    opacity: 1;
    box-shadow: #000 0em 0em 0em;
}

.sj-extraslider .extraslider-inner .item-wrap.style11 .item-info {
    position: absolute;
    top: 0;
    left: 0;
    height: 100%;
    text-align: center;
    padding: 0;
    background-color: #333;
    -webkit-transform: rotate(0deg) scale(1);
    -moz-transform: rotate(0deg) scale(1);
    -o-transform: rotate(0deg) scale(1);
    -ms-transform: rotate(0deg) scale(1);
    transform: rotate(0deg) scale(1);
    -ms-filter: "progid: DXImageTransform.Microsoft.Alpha(Opacity=0)";
    filter: alpha(opacity=0);
    opacity: 0;
    -webkit-transition: all 0.3s ease-out;
    -moz-transition: all 0.3s ease-out;
    -o-transition: all 0.3s ease-out;
    -ms-transition: all 0.3s ease-out;
    transition: all 0.3s ease-out;
}

.sj-extraslider .extraslider-inner .item-wrap.style11 .item-info .item-content {
    padding: 5px;
}

.sj-extraslider .extraslider-inner .item-wrap.style11 .item-title {
    background: #FFF;
    opacity: 0.5;
    filter: alpha(opacity=50);
    font-size: 17px;
    margin-top: 5%;
    padding: 5px;
    text-align: center;
    text-transform: uppercase;
    -webkit-transform: translateY(-200px);
    -moz-transform: translateY(-200px);
    -o-transform: translateY(-200px);
    -ms-transform: translateY(-200px);
    transform: translateY(-200px);
    -webkit-transition: all 0.2s ease-in-out;
    -moz-transition: all 0.2s ease-in-out;
    -o-transition: all 0.2s ease-in-out;
    -ms-transition: all 0.2s ease-in-out;
    transition: all 0.2s ease-in-out;
}

.sj-extraslider .extraslider-inner .item-wrap.style11 .item-price,
.sj-extraslider .extraslider-inner .item-wrap.style11 .item-description {
    text-align: left;
    -webkit-transform: translateY(-200px);
    -moz-transform: translateY(-200px);
    -o-transform: translateY(-200px);
    -ms-transform: translateY(-200px);
    transform: translateY(-200px);
    -webkit-transition: all 0.2s ease-in-out;
    -moz-transition: all 0.2s ease-in-out;
    -o-transition: all 0.2s ease-in-out;
    -ms-transition: all 0.2s ease-in-out;
    transition: all 0.2s ease-in-out;
}

.sj-extraslider .extraslider-inner .item-wrap.style11 .item-readmore {
    background: none repeat scroll 0 0 #000000;
    box-shadow: 0 0 1px #000000;
    color: #FFFFFF;
    display: inline-block;
    padding: 2px 10px;
    text-align: center;
    -webkit-transform: translateY(-200px);
    -moz-transform: translateY(-200px);
    -o-transform: translateY(-200px);
    -ms-transform: translateY(-200px);
    transform: translateY(-200px);
    -webkit-transition: all 0.2s ease-in-out;
    -moz-transition: all 0.2s ease-in-out;
    -o-transition: all 0.2s ease-in-out;
    -ms-transition: all 0.2s ease-in-out;
    transition: all 0.2s ease-in-out;
}

.sj-extraslider .extraslider-inner .item-wrap.style11:hover img {
    -webkit-transform: rotate(720deg) scale(0);
    -moz-transform: rotate(720deg) scale(0);
    -o-transform: rotate(720deg) scale(0);
    -ms-transform: rotate(720deg) scale(0);
    transform: rotate(720deg) scale(0);
    filter: alpha(opacity=0);
    opacity: 0;
    box-shadow: #000 0em 0em 0em;
}

.sj-extraslider .extraslider-inner .item-wrap.style11:hover .item-info {
    filter: alpha(opacity=100);
    opacity: 1;
    -webkit-transform: translateY(0px) rotate(0deg);
    -moz-transform: translateY(0px) rotate(0deg);
    -o-transform: translateY(0px) rotate(0deg);
    -ms-transform: translateY(0px) rotate(0deg);
    transform: translateY(0px) rotate(0deg);
    -webkit-transition-delay: 0.4s;
    -moz-transition-delay: 0.4s;
    -o-transition-delay: 0.4s;
    -ms-transition-delay: 0.4s;
    transition-delay: 0.4s;
}

.sj-extraslider .extraslider-inner .item-wrap.style11:hover .item-title {
    -webkit-transform: translateY(0px);
    -moz-transform: translateY(0px);
    -o-transform: translateY(0px);
    -ms-transform: translateY(0px);
    transform: translateY(0px);
    -webkit-transition-delay: 0.7s;
    -moz-transition-delay: 0.7s;
    -o-transition-delay: 0.7s;
    -ms-transition-delay: 0.7s;
    transition-delay: 0.7s;
}

.sj-extraslider .extraslider-inner .item-wrap.style11:hover .item-description {
    -webkit-transform: translateY(0px);
    -moz-transform: translateY(0px);
    -o-transform: translateY(0px);
    -ms-transform: translateY(0px);
    transform: translateY(0px);
    -webkit-transition-delay: 0.6s;
    -moz-transition-delay: 0.6s;
    -o-transition-delay: 0.6s;
    -ms-transition-delay: 0.6s;
    transition-delay: 0.6s;
}

.sj-extraslider .extraslider-inner .item-wrap.style11:hover .item-price,
.sj-extraslider .extraslider-inner .item-wrap.style11:hover .item-readmore {
    -webkit-transform: translateY(0px);
    -moz-transform: translateY(0px);
    -o-transform: translateY(0px);
    -ms-transform: translateY(0px);
    transform: translateY(0px);
    -webkit-transition-delay: 0.5s;
    -moz-transition-delay: 0.5s;
    -o-transition-delay: 0.5s;
    -ms-transition-delay: 0.5s;
    transition-delay: 0.5s;
}

.sj-extraslider .extraslider-inner .item-wrap.style11 .item-readmore a {
    color: #FFF;
}

.sj-extraslider .extraslider-inner .item-wrap.style11 .item-title a {
    color: #000;
    text-transform: uppercase;
    font-weight: bold;
}

.sj-extraslider .extraslider-inner .item-wrap.style11 .item-price,
.sj-extraslider .extraslider-inner .item-wrap.style10 .item-price {
    text-align: center;
    color: #F30000;
}
