/* VirtueMart Admin Area */

.virtuemart-admin-area { position: relative; border: hidden #b4b4b4 1px; -moz-border-radius-bottomleft: 6px; -moz-border-radius-bottomright: 6px; -webkit-border-bottom-left-radius: 6px; -webkit-border-bottom-right-radius: 6px; display: -webkit-flex; display: flex; overflow: visible; min-height: 540px; }
.virtuemart-admin-area .menu-wrapper {min-width: 200px; width: 220px; border-right: solid #b4b4b4 1px;border-left: solid #b4b4b4 1px;margin-left: 5px;}
.virtuemart-admin-area.menu-collapsed .menu-wrapper {position: relative; width: 31px; min-width: 31px; z-index: 10;}
.virtuemart-admin-area .admin-content {margin: 0;-webkit-flex-basis: 99%; flex-basis: 99%;}
.virtuemart-admin-area .btn.btn-small { margin-bottom: 5px;}
#header {  background: #ededed;  border-bottom: 1px solid #D3D3D3;}
.ratingbox{position:relative;display:block;width:120px;height:24px;background:url(../../../../../components/com_virtuemart/assets/images/color-stars.png) repeat-x scroll 0 bottom transparent}
.ratingbox span{background:url(../../../../../components/com_virtuemart/assets/images/color-stars.png) repeat-x;display:block;width:1%;height:24px;position:absolute}
.stars-orange{background-position:0 0 !important;}
.stars-red{background-position:0 -54px !important;}
.stars-green{background-position:0 -108px !important; }
.stars-blue{background-position:0 -162px !important;}
.stars-purple{background-position:0 -216px !important;}


/* Overwriting Joomla Admin Template */

/* Toolbar */
#element-box, #toolbar-box, #submenu-box {padding: 0 !important;}
#element-box .t, #element-box .b {display: none;}
#content-box #element-box .m, #content-box .m {border: none;padding: 0px;background: none;}
#content-box #toolbar-box {border-top: solid #b4b4b4 1px;border-left: solid #b4b4b4 1px;border-right: solid #b4b4b4 1px;margin: 0px;padding:0;-moz-border-radius: 6px 6px 0 0;
-webkit-border-radius:6px 6px 0 0;background: #fff url(../images/admin_ui/head_bg.png) center center repeat-x;}
#content-box #toolbar-box .m {border: solid #fff 1px;padding: 7px 10px 4px 10px;background: none repeat scroll 0 0 transparent;min-height: 62px;
-moz-border-radius: 6px 6px 0 0;
-webkit-border-top-left-radius:6px;
-webkit-border-radius:6px 6px 0 0;text-shadow: 0px -1px 1px #fff;}
#content-box #toolbar-box a.toolbar {border: none;}
#content-box #toolbar-box .m .header {color: #444444;font-weight: normal;padding: 0px 0px 0px 60px;margin: 3px 0px 0px 0px;background-position: left center;background-repeat: no-repeat;}
#content-box #toolbar-box .t, #content-box #toolbar-box .b {display: none;}
.bartext { display: block;font-size: 12px;font-weight: bold;line-height: 32px;vertical-align: inherit;white-space: nowrap;width: auto !important;}
/* Pagination Override Bluestork */
.pagination div.limit {display: inline-flex;}
.list-footer.pagination.pagination-toolbar div.limit {float: right;}
div#limit_chzn {margin: 0 0 0 6px;}
div#limit_chzn .chzn-search {display: none;}

/* System Messages overide */
#system-message {margin: 0px !important;overflow: auto;}
#system-message dd.message {background: #4693BB url(../images/admin_ui/saved_background.png) top repeat-x ; max-height: 400px; overflow: auto;}
#system-message dd.message ul {color: #000; background: url("../images/icon_32/information.png") no-repeat 8px center transparent;}
#system-message dd.message ul ,#system-message dd.error ul,#system-message dd.notice ul{margin: 0px;    border-bottom: 1px solid #84A7DB !important;   border-top: 0px !important;;}

/* System Messages VM2 */
#system-message dt.save,#system-message dt.remove,#system-message dt.cancel {display: none;}
/* info message in dark grey */
#system-message dd.remove,#system-message dd.save,#system-message dd.cancel {color: #F4F6F8; background: #7c7d7f url(../images/admin_ui/tabs-ul-background.png) top repeat-x !important;}
/* message in RED */
dl#system-message dd.error,l#system-message dd ul .vmdebug { background: #ffffff url(../images/admin_ui/save_bg.png) top repeat !important;}
/* message in RED */
dl#system-message dd.notice { background: #ededed !important;}
/* message icons */
#system-message dd.message ul {background: url("../images/icon_32/information.png") no-repeat scroll 8px center transparent !important;}
#system-message dd.notice ul {background: url("../images/icon_32/notice.png") no-repeat scroll 8px center transparent !important;}
#system-message dd.remove ul {background: url("../images/icon_32/bin.png") no-repeat scroll 8px center transparent !important;}
#system-message dd.save ul {background: url("../images/icon_32/disk.png") no-repeat scroll 8px center transparent !important;}
#system-message dd.cancel ul {background: url("../images/icon_32/cancel.png") no-repeat scroll 8px center transparent !important;}
#system-message dd ul .vmdebug{background: url("../images/icon_32/elements_16.png") no-repeat scroll 0px top transparent !important;display: block;}
#system-message dd.error ul {background: url("../images/icon_32/exclamation.png") no-repeat scroll 8px center transparent !important;}

fieldset input,fieldset textarea,fieldset select,fieldset img,fieldset button{float:right;width:auto;margin:5px 5px 5px 0}
input.readonly{  border: 0 none;}
/*.adminform {border: 0 none;}*/
.adminform input.readonly{ text-align:right; border: 0 none; font-size: 0.909em;font-weight: normal; color:#000; width:75px }
/* vmdebug */
.vmdebug pre{ padding-left: 32px;}

.adminform th{text-align: right!important;}
.admin-checkbox{width:25px !important;align:center;text-align:center;padding: 4px !important;}
.admin-dates{width:5%;min-width:110px}

dl#system-message dd .vmdebug  { font-size:10px; }
/* Fieldset */
.virtuemart-admin-area fieldset {
border-radius: 6px;
-moz-border-radius: 6px;
-webkit-border-radius: 6px;
margin-bottom: 10px;
border: 1px #CCC solid;
padding: 5px;
text-align: right;
}

.virtuemart-admin-area .key {min-width: 160px;}
.virtuemart-admin-area fieldset legend {padding: 0px 10px;width: inherit;border-bottom:0px}

/* Inputs */
.virtuemart-admin-area fieldset input {float: none !important;clear: none;display: inline-block;}
.virtuemart-admin-area fieldset #custom_fields .key {width:96%;}
.virtuemart-admin-area fieldset label, .virtuemart-admin-area fieldset.adminform label, .virtuemart-admin-area fieldset.adminform span.faux-label {float: none;clear: none;display: inline-block;min-width: 0px;margin:0 5px 0 0;}
/*.virtuemart-admin-area div.tabs {margin-bottom: 240px;}*/
#custom_fields { width: 100%; }
/* Modify message */

textarea {width: 100%;}
/*.datepicker{width: 60px;} seems unused*/
.translator {
    border-left: 4px solid #1FBE42;
    padding-left: 8px ;
}
/* Tabs */

/* The Navigation Area */
/*#admin-ui-tabs {overflow: visible !important;}*/

#admin-ui-tabs ul#tabs {list-style-type:none;margin: 0px;padding: 0px ;background: #7c7d7f url(../images/admin_ui/tabs-ul-background.png) bottom repeat-x;}
#admin-ui-tabs ul#tabs li {vertical-align: top;color: #FFFFFF;cursor: pointer;display: inline-block;vertical-align: middle;font-size: 14px;height: 32px;letter-spacing: 1px;padding: 5px 0 0 0;text-align: center;text-shadow: 0 -1px 1px #000000;}
#admin-ui-tabs ul#tabs li span{    line-height: 12px;padding-top: 10px;vertical-align: middle;}
#admin-ui-tabs ul#tabs li.current {background: #fff url(../images/admin_ui/tabs-li-background.png) top repeat-x;color: #444444;text-shadow: 0px -1px 1px #fff;-moz-border-radius-topleft: 6px;-moz-border-radius-topright: 6px;-webkit-border-top-left-radius: 6px;-webkit-border-top-right-radius: 6px;-moz-box-shadow: 0px -1px 2px #3f3f40;cursor: default;border: 0 none;}

/* The Content Area */
#admin-content .radio input[type="radio"], #admin-content .checkbox input[type="checkbox"] {
    float: left;
    margin: 0 10px 0 0;
}

/*#admin-content {overflow: visible;}
#admin-ui-tabs {overflow: visible !important;}*/
#admin-ui-tabs .tabs {padding: 10px 1px 20px; overflow: visible;}

/*#admin-ui-tabs .tabs table {overflow: auto !important;}*/
/* do not change the line below !!! */
#admin-ui-tabs .dyn-tabs {overflow:auto;display:none;}

/* Table */
table.adminlist .right{text-align: right;}
table.adminlist td.vm-order > span {background-repeat: no-repeat;height: 13px;text-align: center;width: 20px;}

/* Admin Menu */
#admin-ui-menu {border-bottom:1px solid #94B1CF;}
#admin-ui-menu h3.menu-title {position: relative; height: 30px; background: #00A1DF;cursor:pointer;border-top: 1px solid rgba(255, 255, 255, 0.15);;margin: 0px;color: #efefef;font-size: 14px;font-weight: normal;color: #333;text-transform: uppercase;}
.menu-title-wrapper { display: block; height: 30px; line-height: 30px;}
.menu-collapsed #admin-ui-menu h3.menu-title, .menu-collapsed #admin-ui-menu .menu-list ul li a {white-space: nowrap;}
.menu-vmlogo {color: #333333;cursor: pointer;font-size: 12px;font-weight: normal;margin: 0;padding: 0;}
.menu-notice {background-color: #fff;margin: 8px 30px;padding: 2px;text-align: center;}
.menu-notice a:link ,.menu-notice a span {color :#000 ;}
#admin-ui-menu h3.current,.menu-collapsed #admin-ui-menu h3.menu-title, #admin-ui-menu h3.menu-title:hover {   color :#FFFFFF ; }
.vm-installed-version {margin-top: 15px;  text-align: center; color:#999 }
#admin-ui-menu .menu-list {border-top: 1px solid #94B1CF;}
#admin-ui-menu .menu-list ul {margin: 0px;padding: 0;}
#admin-ui-menu .menu-list ul li {list-style: none;}
#admin-ui-menu .menu-list ul li a { color: #000000;display: block;font-size: 14px; line-height: 14px; margin: 0;text-decoration: none; opacity : 0.8; background: #fafafa; color: #000000;display: block;font-size: 14px;margin: 0;text-decoration: none; opacity : 0.8; border: 1px solid transparent; border-bottom-color: #fbfbfb; border-right-width: 0;
    -moz-opacity : 0.8;
    -ms-filter: "alpha(opacity=90)"; /* IE 8 */
    filter : alpha(opacity=90); /* IE < 8 */  }
#admin-ui-menu .menu-list ul li a:hover {color: #888; opacity :1;-moz-opacity : 1; -ms-filter: "alpha(opacity=100)"; /* IE 8 */
    filter : alpha(opacity=100); /* IE < 8 */ }


#admin-ui-tabs .not-active .hasTip {   opacity : 0.5;
    -moz-opacity : 0.5;
    -ms-filter: "alpha(opacity=50)"; /* IE 8 */
    filter : alpha(opacity=50); /* IE < 8 */
font-weight: normal;
}

/*////////////////////////////////////
////////////// Basics ////////////////
////////////////////////////////////*/
.inline {display: inline-block;vertical-align: middle;}
.clear {clear: both;}
.floatleft {float: left;}
.floatright{float: right;}
.center{text-align: center}
.right {text-align: right;}

/*////////////////////////////////////
///////////// All Width`s ////////////
////////////////////////////////////*/
.width1{width:1%}.width2{width:2%}.width3{width:3%}.width4{width:4%}.width5{width:5%}.width6{width:6%}.width7{width:7%}.width8{width:8%}.width9{width:9%}.width10{width:10%}.width11{width:11%}.width12{width:12%}.width13{width:13%}.width14{width:14%}.width15{width:15%}.width16{width:16%}.width17{width:17%}.width18{width:18%}.width19{width:19%}.width20{width:20%}.width21{width:21%}.width22{width:22%}.width23{width:23%}.width24{width:24%}.width25{width:25%}.width26{width:26%}.width27{width:27%}.width28{width:28%}.width29{width:29%}.width30{width:30%}.width31{width:31%}.width32{width:32%}.width33{width:33%}.width34{width:34%}.width35{width:35%}.width36{width:36%}.width37{width:37%}.width38{width:38%}.width39{width:39%}.width40{width:40%}.width41{width:41%}.width42{width:42%}.width43{width:43%}.width44{width:44%}.width45{width:45%}.width46{width:46%}.width47{width:47%}.width48{width:48%}.width49{width:49%}.width50{width:50%}.width51{width:51%}.width52{width:52%}.width53{width:53%}.width54{width:54%}.width55{width:55%}.width56{width:56%}.width57{width:57%}.width58{width:58%}.width59{width:59%}.width60{width:60%}.width61{width:61%}.width62{width:62%}.width63{width:63%}.width64{width:64%}.width65{width:65%}.width66{width:66%}.width67{width:67%}.width68{width:68%}.width69{width:69%}.width70{width:70%}.width71{width:71%}.width72{width:72%}.width73{width:73%}.width74{width:74%}.width75{width:75%}.width76{width:76%}.width77{width:77%}.width78{width:78%}.width79{width:79%}.width80{width:80%}.width81{width:81%}.width82{width:82%}.width83{width:83%}.width84{width:84%}.width85{width:85%}.width86{width:86%}.width87{width:87%}.width88{width:88%}.width89{width:89%}.width90{width:90%}.width91{width:91%}.width92{width:92%}.width93{width:93%}.width94{width:94%}.width95{width:95%}.width96{width:96%}.width97{width:97%}.width98{width:98%}.width99{width:99%}.width100{width:100%}


/* Icons */
.print_32, .icon-32-print {background: url(../images/icon_32/printer.png) no-repeat transparent; float:left;height: 32px;margin: auto;text-align: center;width: 32px;}
.invoice_32, .invoice-32-print {background: url(../images/icon_32/invoice.png) no-repeat transparent; float:left;height: 32px;margin: auto;text-align: center;width: 32px;}
.invoicenew_32, .invoice-32-print {background: url(../images/icon_32/invoicenew.png) no-repeat transparent; float:left;height: 32px;margin: auto;text-align: center;width: 32px;}
.deliverynote_32, .deliverynote-32-print {background: url(../images/icon_32/deliverynote.png) no-repeat transparent; float:left;height: 32px;margin: auto;text-align: center;width: 32px;}
.deliverynotenew_32, .deliverynote-32-print {background: url(../images/icon_32/deliverynotenew.png) no-repeat transparent; float:left;height: 32px;margin: auto;text-align: center;width: 32px;}
.control-group{display: table;margin-top: 15px;}
.control-label {float: right;padding: 0 5px 0 0;width: 250px;}
.control-input {float: right;margin: 0 0 0 50px;}
.control-input textarea{width:100%;min-width:450px;}
.control-field h3 {font-weight: bold;padding:5px;background-color: #cacaca}
.control-input input { width: initial;}
.control-label .level1 {background-color: #7c7d7f !important;font-weight: bold;padding: 5px;float: none;clear: both;}

#limit {width:60px;}

/* jqeury ui autocomplete */
.ui-widget{margin-top:2em}
.ui-widget-header,.ui-widget-content{padding:.5em 1em}
.ui-widget-header h2{margin:0;padding:0}
.ui-autocomplete{width:600px;height:300px}
.ui-autocomplete li{background:none repeat scroll 0 0 #FFF;display:inline;float:right;list-style:none outside none;position:relative;margin:0;padding:0}
.ui-autocomplete li a{border:none !important}
.vmpayment_description,.vmshipment_description{margin-left:2px}
/* #plugin-Container{display:table} */
.vm2-modallink{height:16px;margin-left:3px;width:16px;display:inline-block;background:url(../images/admin_ui/icon_external_link.gif) no-repeat scroll left top transparent}
.vmquote{background-color:#E9ECEF;border:1px solid #CCC;color:#254D78;font-size:12px;margin:4px;padding:10px}
ul.newsfeed{list-style:none!important;text-align:right;padding:0}
ul.newsfeed li{font-size:120%;line-height:150%;margin:0;padding:0 0 0 25px}
.cpanel{padding-left:25px;text-align:right}
.element-box{background:#fff}
.virtuemart-admin-area input.ordering {max-width: 20px;float: right;}
a.signin-button-link {margin: 5px  10px 5px 0;background: #F0F0F0;border: 1px solid #BDBDBD;padding:10px}
a:hover.signin-button-link {text-decoration:none;background: #D7D7D7;}

.virtuemart-admin-area #menu-wrapper > a { display: block; height: 40px;}
.virtuemart-admin-area #menu-wrapper.menu-collapsed > a {opacity: 0; visibility: hidden;}
.virtuemart-admin-area #menu-wrapper > a img { padding: 0; height: 100%; margin-right: 30px}
.menu-title-wrapper .menu-title-content {padding: 4px 34px 4px 10px;}
.menu-collapsed .menu-title-wrapper .menu-title-content { padding: 7px 10px; margin-right: 31px; background: #00A1DF; border: 0; opacity: 0;}
#element-box .menu-collapsed .menu-title-wrapper .menu-title-content { padding: 8px 10px;}
.menu-collapsed .menu-title-wrapper:hover .menu-title-content { opacity: 1; border: 1px solid #17508C;}
.virtuemart-admin-area .menu-wrapper, .virtuemart-admin-area .toggler, .virtuemart-admin-area #menu-wrapper.menu-collapsed > a,
.menu-collapsed #admin-ui-menu h3.menu-title, .menu-collapsed #admin-ui-menu .menu-list ul li a,
.menu-title-wrapper .menu-title-content, .menu-collapsed .menu-subtitle {-webkit-transition: all 400ms; -moz-transition: all 400ms; -ms-transition: all 400ms; -o-transition: all 400ms;}

#admin-ui-menu .menu-list ul, #admin-ui-menu .menu-list ul li, #admin-ui-menu .menu-list ul li a {vertical-align: middle;width: 100%;}
#admin-ui-menu .menu-list ul { display: table; position: static;}
#admin-ui-menu .menu-list ul li { display: table-row; position: static; padding: 4px 0;}
#admin-ui-menu .menu-list ul li a { display: table-cell; height: 30px; padding: 0 6px 0 34px; padding: 4px 34px 4px 10px; position: relative;}
.menu-collapsed #admin-ui-menu h3.menu-title, .menu-collapsed #admin-ui-menu .menu-list ul li a { white-space: nowrap; padding-top: 0; padding-bottom: 0; overflow: hidden;}
.menu-collapsed #admin-ui-menu h3.menu-title:hover, .menu-collapsed #admin-ui-menu .menu-list ul li a:hover {overflow: visible;}
.menu-collapsed #admin-ui-menu .menu-list ul li a { padding: 0; width: 30px; height: 30px;}
.menu-collapsed .menu-subtitle { display: block; background: #efefef; border: 0; height: 31px; line-height: 30px; padding: 0 10px; position: absolute; right: 30px; top: -2px; opacity: 0;}
.menu-collapsed a:hover .menu-subtitle{ opacity: 1; border: 1px solid #ccc;}
.menu-collapsed #admin-ui-menu h3.menu-title:hover, .menu-collapsed #admin-ui-menu .menu-list ul li a:hover { width: auto;}
.menu-collapsed .vm-installed-version { opacity: 0;}
.menu-collapsed > div > div > p {overflow: hidden;}
.vm-lang-list-container{ z-index:20;margin-right: 15px;}
.vm-lang-list-container img{float:right;}
.vm-drop{min-width:100px;width:100%;max-width:207px;}

.pr-price-derivated {color:#808080}

#show_hide_prices.admintable tr:nth-child(2n) {background-color: #f8f8f8;}
#show_hide_prices.admintable th, #show_hide_prices.admintable td {min-width: 72px;padding: 0 4px;text-align: center;border-left: 1px solid #ccc;}
#show_hide_prices.admintable th:first-child, #show_hide_prices.admintable td:first-child {border-left: 0;text-align: left;}